@@ -198,7 +198,7 @@ class Snowflake():
             sql = queries.insert_type(type)
             cursor.execute(sql)
         db.commit()
-        print("graph ID: " + self.id)
+        print("graph ID: " + str(self.id))
 
         edgefeatures = []
         #cursor.execute("BEGIN TRANSACTION;")
